@@ -13,7 +13,7 @@ use secrecy::SecretString;
 use serde::{de, ser};
 use serde_json as json;
 
-use crate::location::Location;
+use crate::location::{AwsRegion, AzureRegion, Location};
 use crate::output::Output;
 use crate::v0;
 
@@ -188,7 +188,7 @@ impl Api {
     pub(crate) async fn get_aws_location(
         &self,
         name: &v0::StateName,
-        region: v0::AwsRegion,
+        region: AwsRegion,
     ) -> ApiResult<v0::StateLocationAws> {
         let path = format!(
             "/states/{name}/locations/aws/{region}",
@@ -201,7 +201,7 @@ impl Api {
     pub(crate) async fn add_aws_location(
         &self,
         name: &v0::StateName,
-        region: v0::AwsRegion,
+        region: AwsRegion,
     ) -> ApiResult<v0::StateLocationAws> {
         let path = format!("/states/{name}/locations/aws", name = name);
         let body = v0::CreateStateLocationAwsDto { region };
@@ -211,7 +211,7 @@ impl Api {
     pub(crate) async fn del_aws_location(
         &self,
         name: v0::StateName,
-        region: v0::AwsRegion,
+        region: AwsRegion,
     ) -> ApiResult<v0::StateLocationAws> {
         let path = format!(
             "/states/{name}/locations/aws/{region}",
@@ -224,7 +224,7 @@ impl Api {
     pub(crate) async fn get_azure_location(
         &self,
         name: &v0::StateName,
-        region: v0::AzureRegion,
+        region: AzureRegion,
     ) -> ApiResult<v0::StateLocationAzure> {
         let path = format!(
             "/states/{name}/locations/azure/{region}",
@@ -237,7 +237,7 @@ impl Api {
     pub(crate) async fn add_azure_location(
         &self,
         name: &v0::StateName,
-        region: v0::AzureRegion,
+        region: AzureRegion,
     ) -> ApiResult<v0::StateLocationAzure> {
         let path = format!("/states/{name}/locations/azure", name = name);
         let body = v0::CreateStateLocationAzureDto { region };
@@ -247,7 +247,7 @@ impl Api {
     pub(crate) async fn del_azure_location(
         &self,
         name: v0::StateName,
-        region: v0::AzureRegion,
+        region: AzureRegion,
     ) -> ApiResult<v0::StateLocationAzure> {
         let path = format!(
             "/states/{name}/locations/azure/{region}",
