@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
 // Use is subject to license terms.
 //
 
@@ -36,11 +36,9 @@ impl<T: fmt::Display> Diagnose for kube::Result<T> {
 
 impl Kubectl {
     pub(crate) async fn check_cluster(&self) -> impl Stream<Item = Result<String, String>> + '_ {
-        let statehub_kubectl = self
-            .get_client()
-            .await
-            .map(statehub_cluster_operator::cluster::Kubectl::new)
-            .unwrap();
+        let config = self.get_config().await.unwrap();
+        let statehub_kubectl =
+            statehub_cluster_operator::cluster::Operator::with_config(config).unwrap();
 
         stream!(
             let crd = self
