@@ -3,12 +3,6 @@
 // Use is subject to license terms.
 //
 
-use std::collections::HashMap;
-use std::convert::TryFrom;
-
-use k8s_openapi::api::core::v1::Node;
-use kube::api::ResourceExt;
-
 use super::*;
 
 const K8S_TOPOLOGY_REGION: &str = "topology.kubernetes.io/region";
