@@ -1,5 +1,5 @@
 //
-// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
+// Copyright (c) 2022 RepliXio Ltd. All rights reserved.
 // Use is subject to license terms.
 //
 
@@ -14,7 +14,6 @@ use dialoguer::{theme, Confirm, Input, MultiSelect, Select};
 use futures::StreamExt;
 use itertools::Itertools;
 use serde::{de, Deserialize, Serialize};
-use serde_json as json;
 
 use crate::api;
 use crate::k8s;
@@ -195,15 +194,15 @@ enum Command {
         #[clap(
             help = "Skip setting up default storage class",
             long,
-            conflicts_with = "default_storage_class"
+            conflicts_with = "default-storage-class"
         )]
         no_default_storage_class: bool,
 
         #[clap(
             help = "The name of the state to configure as default storage class",
             long,
-            conflicts_with_all = &["no_state", "no_default_storage_class"],
-            visible_alias = "default_sc",
+            conflicts_with_all = &["no-state", "no-default-storage-class"],
+            visible_alias = "default-sc",
         )]
         default_storage_class: Option<String>,
 
@@ -692,13 +691,14 @@ impl Command {
 }
 
 impl Cli {
-    pub(crate) async fn execute() -> anyhow::Result<()> {
+    pub(crate) async fn execute() -> super::CliResult {
         let cli = Self::parse();
         let json = cli.json;
 
-        cli.dispatch()
-            .await
-            .or_else(|err| if json { json_error(err) } else { Err(err) })
+        let result = cli.dispatch().await;
+        super::CliResult::new(json, result)
+
+        // .or_else(|err| if json { json_error(err) } else { Err(err) })
     }
 
     async fn config(&self) -> anyhow::Result<Config> {
@@ -1652,12 +1652,3 @@ fn parse_params(text: &str) -> anyhow::Result<(String, String)> {
         .map(|(key, value)| (key.to_string(), value.to_string()))
         .ok_or_else(|| anyhow::anyhow!("Invalid format: should be key=value"))
 }
-
-fn json_error(err: anyhow::Error) -> anyhow::Result<()> {
-    if let Some(err) = err.downcast_ref::<v0::Error>() {
-        println!("{}", json::to_string(err)?);
-        Ok(())
-    } else {
-        Err(err)
-    }
-}
